@@ -1,13 +1,37 @@
+import random
+from time import sleep
 from json.decoder import JSONDecodeError
 
 import requests
 
-from ..utils import _get_logger
+from requests import ConnectionError
+from urllib3.exceptions import ProtocolError
+
+from bb_wrapper.utils import _get_logger
 
 
 logger = _get_logger("requests")
 
 
+def retry_request(max_retries=5):
+    def wrapper(func):
+        def inner(*args, counter=None, **kwargs):
+            counter = counter if counter is not None else max_retries
+            try:
+                sleep_time = random.randint(1, 90) / 100
+                sleep(sleep_time)
+                return func(*args, **kwargs)
+            except (ConnectionResetError, ConnectionError, ProtocolError):
+                if counter > 0:
+                    counter -= 1
+                    return inner(*args, counter=counter, **kwargs)
+                raise
+
+        return inner
+
+    return wrapper
+
+
 class RequestsWrapper:
     """
     wrapper da lib requests
@@ -97,14 +121,14 @@ class RequestsWrapper:
         """
         raise NotImplementedError("Must implement auth function!")
 
-    @property
-    def _base_url(self):
-        return self.__base_url
-
     @property
     def _authorization_header_data(self):
         return {"Authorization": self._auth}
 
+    @property
+    def _base_url(self):
+        return self.__base_url
+
     def _get_request_info(self, headers=None):
         if not headers:
             headers = self._authorization_header_data
@@ -117,6 +141,7 @@ class RequestsWrapper:
             cert=self.__cert,
         )
 
+    @retry_request(max_retries=3)
     def _delete(self, url, headers=None) -> requests.Response:
         """
         http delete
@@ -132,6 +157,7 @@ class RequestsWrapper:
         response = self._process_response(response)
         return response
 
+    @retry_request(max_retries=3)
     def _get(self, url, headers=None) -> requests.Response:
         """
         http get
@@ -147,6 +173,7 @@ class RequestsWrapper:
         response = self._process_response(response)
         return response
 
+    @retry_request(max_retries=3)
     def _post(self, url, data, headers=None, use_json=True) -> requests.Response:
         """
         http post
@@ -169,6 +196,7 @@ class RequestsWrapper:
         response = self._process_response(response)
         return response
 
+    @retry_request(max_retries=3)
     def _put(self, url, data, headers=None, use_json=True) -> requests.Response:
         """
         http put
@@ -189,6 +217,7 @@ class RequestsWrapper:
         response = self._process_response(response)
         return response
 
+    @retry_request(max_retries=3)
     def _patch(self, url, data, headers=None, use_json=True) -> requests.Response:
         request_info = self._get_request_info(headers)
         if use_json:
